==> blackfin.3.0.0.sjis.tar.gz: jsp/config/blackfin/_common_bf537/hw_serial.h <==
/*
 *  TOPPERS/JSP Kernel
 *      Toyohashi Open Platform for Embedded Real-Time Systems/
 *      Just Standard Profile Kernel
 * 
 *  Copyright (C) 2000-2003 by Embedded and Real-Time Systems Laboratory
 *                              Toyohashi Univ. of Technology, JAPAN
 * 
 *  L쌠҂́Cȉ (1)`(4) ̏CFree Software Foundation 
 *  ɂČ\Ă GNU General Public License  Version 2 ɋL
 *  qĂ𖞂ꍇɌC{\tgEFAi{\tgEFA
 *  ς̂܂ށDȉjgpEEρEĔzziȉC
 *  pƌĂԁj邱Ƃ𖳏ŋD
 *  (1) {\tgEFA\[XR[ȟ`ŗpꍇɂ́CL̒
 *      \C̗pщL̖ۏ؋K肪Ĉ܂܂̌`Ń\[
 *      XR[hɊ܂܂Ă邱ƁD
 *  (2) {\tgEFACCu`ȂǁC̃\tgEFAJɎg
 *      pł`ōĔzzꍇɂ́CĔzzɔhLgip
 *      ҃}jAȂǁjɁCL̒쌠\C̗pщL
 *      ̖ۏ؋Kfڂ邱ƁD
 *  (3) {\tgEFAC@ɑgݍނȂǁC̃\tgEFAJɎg
 *      płȂ`ōĔzzꍇɂ́Ĉꂩ̏𖞂
 *      ƁD
 *    (a) ĔzzɔhLgip҃}jAȂǁjɁCL̒
 *        쌠\C̗pщL̖ۏ؋Kfڂ邱ƁD
 *    (b) Ĕzž`ԂCʂɒ߂@ɂāCTOPPERSvWFNg
 *        񍐂邱ƁD
 *  (4) {\tgEFA̗pɂ蒼ړI܂͊ԐړIɐ邢Ȃ鑹
 *      QCL쌠҂TOPPERSvWFNgƐӂ邱ƁD
 * 
 *  {\tgEFÁCۏ؂Œ񋟂Ă̂łDL쌠҂
 *  TOPPERSvWFNǵC{\tgEFAɊւāC̓Kp\
 *  ܂߂āCȂۏ؂sȂD܂C{\tgEFA̗pɂ蒼
 *  ړI܂͊ԐړIɐȂ鑹QɊւĂC̐ӔC𕉂ȂD
 * 
 */

/*
 *  VAI/OfoCXiSIOjhCoiBlackfin UARTpj
 *
 *   ̃t@ĆATOPPERS/JSP 1.4.2 config/sh3/ms7727cp01/hw_serial.h
 *   l[A̎ʎqύX̂łB
 * 
 *   ̃t@C͉ʂ̃foCXEANZXE[`𑩂˂ďʂ̑wɓn
 *   ߂̂̂łBBlackfin̊OɂVATOPPERS/JSPŊǗȂ
 *   ̂ȂAύXKv͂ȂB
 */

#ifndef _HW_SERIAL_H_
#define _HW_SERIAL_H_

#include <s_services.h>

#include "uart.h"

#ifdef __GNUC__         // gcc
#include "../cdefbf537.h"
#elif defined(__ECC__)  // visualdsp
#include <cdefbf53x.h>
#else
#error "Compiler is not supported"
#endif


/*
 *  SIOhCȍ[`
 */
#define sio_initialize  uart_initialize

#ifndef _MACRO_ONLY
/*
 *  VAI/O|[g̃I[v
 */
Inline SIOPCB *
sio_opn_por(ID siopid, VP_INT exinf)
{
    SIOPCB  *siopcb;
    UW regBase;
    
    /*
     *  foCXˑ̃I[vD
     */
    siopcb = uart_opn_por(siopid, exinf);

	/*
	* Enable Corrensponding Interrupt at IMASK
	*/
    regBase = siopcb->siopinib->reg_base;
    if ( regBase == UART0_ADDRESS ) {        // UART0̏ꍇ
	    ena_int( INTNO_UART0_TX );
	    ena_int( INTNO_UART0_RX );
        *pPORT_MUX  &= ~0x0008;   // @\UART0ɊU
        *pPORTF_FER |=  0x0003;   // PF0,PF1UART0ɊU
    }
    else if ( regBase == UART1_ADDRESS ){    // uart1̏ꍇ
        ena_int( INTNO_UART1_TX );
        ena_int( INTNO_UART1_RX );
        *pPORT_MUX  &= ~0x0010;   // @\UART0ɊU
        *pPORTF_FER |=  0x000C;   // PF2,PF3UART0ɊU
    }
	
    return(siopcb);
}

/*
 *  VAI/O|[g̃N[Y
 */
Inline void
sio_cls_por(SIOPCB *siopcb)
{
    UW regBase;

	/*
	* Enable Corrensponding Interrupt at IMASK
	*/
    regBase = siopcb->siopinib->reg_base;
    if ( regBase == UART0_ADDRESS ) {        // uart0̏ꍇ
       dis_int( INTNO_UART0_TX );
       dis_int( INTNO_UART0_RX );
    }
    else if ( regBase == UART1_ADDRESS ){    // uart1̏ꍇ
       dis_int( INTNO_UART1_TX );
       dis_int( INTNO_UART1_RX );
    }

    /*
     *  foCXˑ̃N[YD
     */
    uart_cls_por(siopcb);
}


/*
 *  SIO̊݃nh
 */
#define sio0_rx_handler uart0_rx_isr
#define sio0_tx_handler uart0_tx_isr
#define sio1_rx_handler uart1_rx_isr
#define sio1_tx_handler uart1_tx_isr

/*
 *  VAI/O|[gւ̕M
 */
#define sio_snd_chr uart_snd_chr

/*
 *  VAI/O|[g̕M
 */
#define sio_rcv_chr uart_rcv_chr

/*
 *  VAI/O|[g̃R[obN̋
 */
#define sio_ena_cbr uart_ena_cbr

/*
 *  VAI/O|[g̃R[obN̋֎~
 */
#define sio_dis_cbr uart_dis_cbr

/*
 *  VAI/O|[g̑M\R[obN
 */
#define sio_ierdy_snd   uart_ierdy_snd

/*
 *  VAI/O|[g̎MʒmR[obN
 */
#define sio_ierdy_rcv   uart_ierdy_rcv

#endif /* _MACRO_ONLY */
#endif /* _HW_SERIAL_H_ */

==> blackfin.3.1.1.sjis.tar.gz: jsp/config/blackfin/_common_bf537/hw_serial.h <==
/*
 *  TOPPERS/JSP Kernel
 *      Toyohashi Open Platform for Embedded Real-Time Systems/
 *      Just Standard Profile Kernel
 *
 *  Copyright (C) 2000-2003 by Embedded and Real-Time Systems Laboratory
 *                              Toyohashi Univ. of Technology, JAPAN
 *
 *  L쌠҂́Cȉ (1)`(4) ̏CFree Software Foundation
 *  ɂČ\Ă GNU General Public License  Version 2 ɋL
 *  qĂ𖞂ꍇɌC{\tgEFAi{\tgEFA
 *  ς̂܂ށDȉjgpEEρEĔzziȉC
 *  pƌĂԁj邱Ƃ𖳏ŋD
 *  (1) {\tgEFA\[XR[ȟ`ŗpꍇɂ́CL̒
 *      \C̗pщL̖ۏ؋K肪Ĉ܂܂̌`Ń\[
 *      XR[hɊ܂܂Ă邱ƁD
 *  (2) {\tgEFACCu`ȂǁC̃\tgEFAJɎg
 *      pł`ōĔzzꍇɂ́CĔzzɔhLgip
 *      ҃}jAȂǁjɁCL̒쌠\C̗pщL
 *      ̖ۏ؋Kfڂ邱ƁD
 *  (3) {\tgEFAC@ɑgݍނȂǁC̃\tgEFAJɎg
 *      płȂ`ōĔzzꍇɂ́Ĉꂩ̏𖞂
 *      ƁD
 *    (a) ĔzzɔhLgip҃}jAȂǁjɁCL̒
 *        쌠\C̗pщL̖ۏ؋Kfڂ邱ƁD
 *    (b) Ĕzž`ԂCʂɒ߂@ɂāCTOPPERSvWFNg
 *        񍐂邱ƁD
 *  (4) {\tgEFA̗pɂ蒼ړI܂͊ԐړIɐ邢Ȃ鑹
 *      QCL쌠҂TOPPERSvWFNgƐӂ邱ƁD
 *
 *  {\tgEFÁCۏ؂Œ񋟂Ă̂łDL쌠҂
 *  TOPPERSvWFNǵC{\tgEFAɊւāC̓Kp\
 *  ܂߂āCȂۏ؂sȂD܂C{\tgEFA̗pɂ蒼
 *  ړI܂͊ԐړIɐȂ鑹QɊւĂC̐ӔC𕉂ȂD
 *
 */

/*
 *  VAI/OfoCXiSIOjhCoiBlackfin UARTpj
 *
 *   ̃t@ĆATOPPERS/JSP 1.4.2 config/sh3/ms7727cp01/hw_serial.h
 *   l[A̎ʎqύX̂łB
 *
 *   ̃t@C͉ʂ̃foCXEANZXE[`𑩂˂ďʂ̑wɓn
 *   ߂̂̂łBBlackfin̊OɂVATOPPERS/JSPŊǗȂ
 *   ̂ȂAύXKv͂ȂB
 */

#ifndef _HW_SERIAL_H_
#define _HW_SERIAL_H_

#include <s_services.h>
#include <sil.h>

#include "uart.h"


/*
 *  SIOhCȍ[`
 */
#define sio_initialize  uart_initialize

#ifndef _MACRO_ONLY
/*
 *  VAI/O|[g̃I[v
 */
Inline SIOPCB *
sio_opn_por(ID siopid, VP_INT exinf)
{
    SIOPCB  *siopcb;
    UW regBase;

    /*
     *  foCXˑ̃I[vD
     */
    siopcb = uart_opn_por(siopid, exinf);

	/*
	* Enable Corrensponding Interrupt at IMASK
	*/
    regBase = siopcb->siopinib->reg_base;
    if ( regBase == UART0_ADDRESS ) {        // UART0̏ꍇ
	    ena_int( INTNO_UART0_TX );
	    ena_int( INTNO_UART0_RX );
        *__pPORT_MUX  &= ~0x0008;   // @\UART0ɊU
        *__pPORTF_FER |=  0x0003;   // PF0,PF1UART0ɊU
    }
    else if ( regBase == UART1_ADDRESS ){    // uart1̏ꍇ
        ena_int( INTNO_UART1_TX );
        ena_int( INTNO_UART1_RX );
        *__pPORT_MUX  &= ~0x0010;   // @\UART0ɊU
        *__pPORTF_FER |=  0x000C;   // PF2,PF3UART0ɊU
    }

    return(siopcb);
}

/*
 *  VAI/O|[g̃N[Y
 */
Inline void
sio_cls_por(SIOPCB *siopcb)
{
	/*
	 * łSIC_IMASK̑ΉrbgNAȂBSIC_IMASK̃NA
	 * 댯łBUART̊荞݂ uart_cls_porŋ֎~̂
	 * [łB
	 */

    /*
     *  foCXˑ̃N[YD
     */
    uart_cls_por(siopcb);
}


/*
 *  SIO̊݃nh
 */
#define sio0_rx_handler uart0_rx_isr
#define sio0_tx_handler uart0_tx_isr
#define sio1_rx_handler uart1_rx_isr
#define sio1_tx_handler uart1_tx_isr

/*
 *  VAI/O|[gւ̕M
 */
#define sio_snd_chr uart_snd_chr

/*
 *  VAI/O|[g̕M
 */
#define sio_rcv_chr uart_rcv_chr

/*
 *  VAI/O|[g̃R[obN̋
 */
#define sio_ena_cbr uart_ena_cbr

/*
 *  VAI/O|[g̃R[obN̋֎~
 */
#define sio_dis_cbr uart_dis_cbr

/*
 *  VAI/O|[g̑M\R[obN
 */
#define sio_ierdy_snd   uart_ierdy_snd

/*
 *  VAI/O|[g̎MʒmR[obN
 */
#define sio_ierdy_rcv   uart_ierdy_rcv

#endif /* _MACRO_ONLY */
#endif /* _HW_SERIAL_H_ */
